package com.ruoyi.ems.mapper;

import com.ruoyi.ems.domain.FacsCategory;

import java.util.List;

/**
 * 能源设施/系统分类Mapper接口
 *
 * @author ruoyi
 * @date 2024-07-10
 */
public interface FacsCategoryMapper {
    /**
     * 查询能源设施/系统分类
     *
     * @param id 能源设施/系统分类主键
     * @return 能源设施/系统分类
     */
    FacsCategory selectCategoryById(Long id);

    /**
     * 查询能源设施/系统分类
     *
     * @param code code
     * @return 能源设施/系统分类
     */
    FacsCategory selectCategoryByCode(String code);

    /**
     * 查询能源设施/系统分类列表
     *
     * @return 能源设施/系统分类集合
     */
    List<FacsCategory> selectCategoryAll();

    /**
     * 查询能源设施/系统分类列表
     *
     * @param category 能源设施/系统分类
     * @return 能源设施/系统分类集合
     */
    List<FacsCategory> selectCategoryList(FacsCategory category);

    /**
     * 新增能源设施/系统分类
     *
     * @param category 能源设施/系统分类
     * @return 结果
     */
    int insertCategory(FacsCategory category);

    /**
     * 修改能源设施/系统分类
     *
     * @param category 能源设施/系统分类
     * @return 结果
     */
    int updateCategory(FacsCategory category);

    /**
     * 删除能源设施/系统分类
     *
     * @param id 能源设施/系统分类主键
     * @return 结果
     */
    int deleteCategoryById(Long id);

    /**
     * 批量删除能源设施/系统分类
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteCategoryByIds(Long[] ids);
}
